@@ -1,7 +1,10 @@
+import asyncio
 from time import sleep
 from typing import List
 from urllib.parse import urlparse
 
+import httpx
+
 from agno.document.base import Document
 from agno.document.reader.base import Reader
 from agno.utils.log import log_debug, log_info, logger
@@ -14,11 +17,6 @@ class URLReader(Reader):
         if not url:
             raise ValueError("No url provided")
 
-        try:
-            import httpx
-        except ImportError:
-            raise ImportError("`httpx` not installed. Please install it via `pip install httpx`.")
-
         log_info(f"Reading: {url}")
         # Retry the request up to 3 times with exponential backoff
         for attempt in range(3):
@@ -27,7 +25,7 @@ class URLReader(Reader):
                 break
             except httpx.RequestError as e:
                 if attempt == 2:  # Last attempt
-                    logger.error(f"Failed to fetch PDF after 3 attempts: {e}")
+                    logger.error(f"Failed to fetch URL after 3 attempts: {e}")
                     raise
                 wait_time = 2**attempt  # Exponential backoff: 1, 2, 4 seconds
                 logger.warning(f"Request failed, retrying in {wait_time} seconds...")
@@ -45,20 +43,57 @@ class URLReader(Reader):
             logger.error(f"HTTP error occurred: {e.response.status_code} - {e.response.text}")
             raise
 
-        # Create a clean document name from the URL
+        document = self._create_document(url, response.text)
+        if self.chunk:
+            return self.chunk_document(document)
+        return [document]
+
+    async def async_read(self, url: str) -> List[Document]:
+        """Async version of read method"""
+        if not url:
+            raise ValueError("No url provided")
+
+        log_info(f"Reading async: {url}")
+        async with httpx.AsyncClient() as client:
+            for attempt in range(3):
+                try:
+                    response = await client.get(url)
+                    break
+                except httpx.RequestError as e:
+                    if attempt == 2:  # Last attempt
+                        logger.error(f"Failed to fetch URL after 3 attempts: {e}")
+                        raise
+                    wait_time = 2**attempt
+                    logger.warning(f"Request failed, retrying in {wait_time} seconds...")
+                    await asyncio.sleep(wait_time)
+
+            try:
+                log_debug(f"Status: {response.status_code}")
+                log_debug(f"Content size: {len(response.content)} bytes")
+            except Exception:
+                pass
+
+            try:
+                response.raise_for_status()
+            except httpx.HTTPStatusError as e:
+                logger.error(f"HTTP error occurred: {e.response.status_code} - {e.response.text}")
+                raise
+
+            document = self._create_document(url, response.text)
+            if self.chunk:
+                return await self.chunk_documents_async([document])
+            return [document]
+
+    def _create_document(self, url: str, content: str) -> Document:
+        """Helper method to create a document from URL content"""
         parsed_url = urlparse(url)
         doc_name = parsed_url.path.strip("/").replace("/", "_").replace(" ", "_")
         if not doc_name:
             doc_name = parsed_url.netloc
 
-        # Create a single document with the URL content
-        document = Document(
+        return Document(
             name=doc_name,
             id=doc_name,
             meta_data={"url": url},
-            content=response.text,
+            content=content,
         )
-
-        if self.chunk:
-            return self.chunk_document(document)
-        return [document]
