@@ -17,7 +17,9 @@ class VideoArtifact(Media):
 
 
 class ImageArtifact(Media):
-    url: str  # Remote location for file
+    url: Optional[str] = None  # Remote location for file
+    content: Optional[bytes] = None  # Actual image bytes content
+    mime_type: Optional[str] = None
     alt_text: Optional[str] = None
 
 
@@ -272,7 +274,7 @@ class Image(BaseModel):
 class File(BaseModel):
     url: Optional[str] = None
     filepath: Optional[Union[Path, str]] = None
-    content: Optional[Any] = None
+    content: Optional[Any] = None  # Actual file bytes content
     mime_type: Optional[str] = None
 
     @model_validator(mode="before")
