@@ -7,7 +7,7 @@ from typing import Any, AsyncGenerator, AsyncIterator, Dict, Iterator, List, Lit
 from uuid import uuid4
 
 from agno.exceptions import AgentRunException
-from agno.media import AudioResponse
+from agno.media import AudioResponse, ImageArtifact
 from agno.models.message import Citations, Message, MessageMetrics
 from agno.models.response import ModelResponse, ModelResponseEvent
 from agno.tools.function import Function, FunctionCall
@@ -24,7 +24,9 @@ class MessageData:
     response_redacted_thinking: Any = ""
     response_citations: Optional[Citations] = None
     response_tool_calls: List[Dict[str, Any]] = field(default_factory=list)
+
     response_audio: Optional[AudioResponse] = None
+    response_image: Optional[ImageArtifact] = None
 
     # Data from the provider that we might need on subsequent messages
     response_provider_data: Optional[Dict[str, Any]] = None
@@ -153,6 +155,10 @@ class Model(ABC):
         if len(functions) > 0:
             self._functions = functions
 
+    def reset_tools_and_functions(self) -> None:
+        self._tools = None
+        self._functions = None
+
     def response(self, messages: List[Message]) -> ModelResponse:
         """
         Generate a response from the model.
@@ -341,6 +347,8 @@ class Model(ABC):
             model_response.citations = assistant_message.citations
         if assistant_message.audio_output is not None:
             model_response.audio = assistant_message.audio_output
+        if assistant_message.image_output is not None:
+            model_response.image = assistant_message.image_output
         if provider_response.extra is not None:
             if model_response.extra is None:
                 model_response.extra = {}
@@ -397,6 +405,8 @@ class Model(ABC):
             model_response.citations = assistant_message.citations
         if assistant_message.audio_output is not None:
             model_response.audio = assistant_message.audio_output
+        if assistant_message.image_output is not None:
+            model_response.image = assistant_message.image_output
         if provider_response.extra is not None:
             if model_response.extra is None:
                 model_response.extra = {}
@@ -435,6 +445,10 @@ class Model(ABC):
         if provider_response.audio is not None:
             assistant_message.audio_output = provider_response.audio
 
+        # Add image to assistant message
+        if provider_response.image is not None:
+            assistant_message.image_output = provider_response.image
+
         # Add thinking content to assistant message
         if provider_response.thinking is not None:
             assistant_message.thinking = provider_response.thinking
@@ -714,6 +728,10 @@ class Model(ABC):
 
             should_yield = True
 
+        if model_response.image:
+            if stream_data.response_image is None:
+                stream_data.response_image = model_response.image
+
         if model_response.extra is not None:
             if stream_data.extra is None:
                 stream_data.extra = {}
@@ -1137,7 +1155,7 @@ class Model(ABC):
 
         # Deep copy all attributes
         for k, v in self.__dict__.items():
-            if k in {"response_format", "tools", "_functions", "_function_call_stack"}:
+            if k in {"response_format", "_tools", "_functions", "_function_call_stack"}:
                 continue
             setattr(new_model, k, deepcopy(v, memo))
 
