@@ -5,14 +5,16 @@ from dataclasses import dataclass
 from os import getenv
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Union
+from uuid import uuid4
 
 from pydantic import BaseModel
 
 from agno.exceptions import ModelProviderError
-from agno.media import Audio, File, Image, Video
+from agno.media import Audio, File, ImageArtifact, Video
 from agno.models.base import Model
 from agno.models.message import Citations, Message, MessageMetrics, UrlCitation
 from agno.models.response import ModelResponse
+from agno.utils.gemini import format_function_definitions, format_image_for_message
 from agno.utils.log import log_error, log_info, log_warning
 
 try:
@@ -22,14 +24,12 @@ try:
     from google.genai.types import (
         Content,
         DynamicRetrievalConfig,
-        FunctionDeclaration,
         GenerateContentConfig,
         GenerateContentResponse,
         GenerateContentResponseUsageMetadata,
         GoogleSearch,
         GoogleSearchRetrieval,
         Part,
-        Schema,
         Tool,
     )
     from google.genai.types import (
@@ -39,120 +39,6 @@ except ImportError:
     raise ImportError("`google-genai` not installed. Please install it using `pip install google-genai`")
 
 
-def _format_image_for_message(image: Image) -> Optional[Dict[str, Any]]:
-    # Case 1: Image is a URL
-    # Download the image from the URL and add it as base64 encoded data
-    if image.url is not None:
-        content_bytes = image.image_url_content
-        if content_bytes is not None:
-            try:
-                import base64
-
-                image_data = {
-                    "mime_type": "image/jpeg",
-                    "data": base64.b64encode(content_bytes).decode("utf-8"),
-                }
-                return image_data
-            except Exception as e:
-                log_warning(f"Failed to download image from {image}: {e}")
-                return None
-        else:
-            log_warning(f"Unsupported image format: {image}")
-            return None
-
-    # Case 2: Image is a local path
-    elif image.filepath is not None:
-        try:
-            image_path = Path(image.filepath)
-            if image_path.exists() and image_path.is_file():
-                with open(image_path, "rb") as f:
-                    content_bytes = f.read()
-            else:
-                log_error(f"Image file {image_path} does not exist.")
-                raise
-            return {
-                "mime_type": "image/jpeg",
-                "data": content_bytes,
-            }
-        except Exception as e:
-            log_warning(f"Failed to load image from {image.filepath}: {e}")
-            return None
-
-    # Case 3: Image is a bytes object
-    # Add it as base64 encoded data
-    elif image.content is not None and isinstance(image.content, bytes):
-        import base64
-
-        image_data = {"mime_type": "image/jpeg", "data": base64.b64encode(image.content).decode("utf-8")}
-        return image_data
-    else:
-        log_warning(f"Unknown image type: {type(image)}")
-        return None
-
-
-def _convert_schema(schema_dict) -> Optional[Schema]:
-    """
-    Recursively convert a JSON-like schema dictionary to a types.Schema object.
-
-    Parameters:
-        schema_dict (dict): The JSON schema dictionary with keys like "type", "description",
-                            "properties", and "required".
-
-    Returns:
-        types.Schema: The converted schema.
-    """
-    schema_type = schema_dict.get("type", "")
-    if isinstance(schema_type, list):
-        schema_type = schema_type[0]
-    schema_type = schema_type.upper()
-    description = schema_dict.get("description", "")
-
-    if schema_type == "OBJECT" and "properties" in schema_dict:
-        properties = {key: _convert_schema(prop_def) for key, prop_def in schema_dict["properties"].items()}
-        required = schema_dict.get("required", [])
-
-        if properties:
-            return Schema(
-                type=schema_type,
-                properties=properties,
-                required=required,
-                description=description,
-            )
-        else:
-            return None
-
-    if schema_type == "ARRAY" and "items" in schema_dict:
-        items = _convert_schema(schema_dict["items"])
-        return Schema(type=schema_type, description=description, items=items)
-    else:
-        return Schema(type=schema_type, description=description)
-
-
-def _format_function_definitions(tools_list):
-    function_declarations = []
-
-    for tool in tools_list:
-        if tool.get("type") == "function":
-            func_info = tool.get("function", {})
-            name = func_info.get("name")
-            description = func_info.get("description", "")
-            parameters_dict = func_info.get("parameters", {})
-
-            parameters_schema = _convert_schema(parameters_dict)
-            # Create a FunctionDeclaration instance
-            function_decl = FunctionDeclaration(
-                name=name,
-                description=description,
-                parameters=parameters_schema,
-            )
-
-            function_declarations.append(function_decl)
-    if function_declarations:
-        return Tool(function_declarations=function_declarations)
-    else:
-        return None
-
-
 @dataclass
 class Gemini(Model):
     """
@@ -191,7 +77,7 @@ class Gemini(Model):
     presence_penalty: Optional[float] = None
     frequency_penalty: Optional[float] = None
     seed: Optional[int] = None
-    response_modalities: Optional[list[str]] = None
+    response_modalities: Optional[list[str]] = None  # "Text" and/or "Image"
     speech_config: Optional[dict[str, Any]] = None
     request_params: Optional[Dict[str, Any]] = None
 
@@ -205,12 +91,15 @@ class Gemini(Model):
     # Gemini client
     client: Optional[GeminiClient] = None
 
-    # The role to map the message role to.
+    # The role to map the Gemini response
     role_map = {
-        "system": "system",
-        "user": "user",
         "model": "assistant",
-        "tool": "tool",
+    }
+
+    # The role to map the Message
+    reverse_role_map = {
+        "assistant": "model",
+        "tool": "user",
     }
 
     def get_client(self) -> GeminiClient:
@@ -224,15 +113,18 @@ class Gemini(Model):
             return self.client
 
         client_params: Dict[str, Any] = {}
-        if not self.vertexai:
+        vertexai = self.vertexai or getenv("GOOGLE_GENAI_USE_VERTEXAI", "false").lower() == "true"
+
+        if not vertexai:
             self.api_key = self.api_key or getenv("GOOGLE_API_KEY")
             if not self.api_key:
                 log_error("GOOGLE_API_KEY not set. Please set the GOOGLE_API_KEY environment variable.")
             client_params["api_key"] = self.api_key
         else:
+            log_info("Using Vertex AI API")
             client_params["vertexai"] = True
             client_params["project"] = self.project_id or getenv("GOOGLE_CLOUD_PROJECT")
-            client_params["location"] = self.location
+            client_params["location"] = self.location or getenv("GOOGLE_CLOUD_LOCATION")
 
         client_params = {k: v for k, v in client_params.items() if v is not None}
 
@@ -311,7 +203,7 @@ class Gemini(Model):
             config["tools"] = [Tool(google_search=GoogleSearch())]
 
         elif self._tools:
-            config["tools"] = [_format_function_definitions(self._tools)]
+            config["tools"] = [format_function_definitions(self._tools)]
 
         config = {k: v for k, v in config.items() if v is not None}
 
@@ -441,7 +333,8 @@ class Gemini(Model):
                 system_message = message.content
                 continue
 
-            role = "model" if role == "assistant" else role
+            # Set the role for the message according to Gemini's requirements
+            role = self.reverse_role_map.get(role, role)
 
             # Add content to the message for the model
             content = message.content
@@ -449,7 +342,7 @@ class Gemini(Model):
             message_parts: List[Any] = []
 
             # Function calls
-            if (not content or role == "model") and message.tool_calls:
+            if (not content or role == "model") and message.tool_calls is not None and len(message.tool_calls) > 0:
                 for tool_call in message.tool_calls:
                     message_parts.append(
                         Part.from_function_call(
@@ -458,18 +351,19 @@ class Gemini(Model):
                         )
                     )
             # Function results
-            elif role == "tool" and message.tool_calls:
+            elif message.tool_calls is not None and len(message.tool_calls) > 0:
                 for tool_call in message.tool_calls:
                     message_parts.append(
                         Part.from_function_response(
                             name=tool_call["tool_name"], response={"result": tool_call["content"]}
                         )
                     )
+            # Regular text content
             else:
                 if isinstance(content, str):
                     message_parts = [Part.from_text(text=content)]
 
-            if message.role == "user":
+            if role == "user" and message.tool_calls is None:
                 # Add images to the message for the model
                 if message.images is not None:
                     for image in message.images:
@@ -477,7 +371,7 @@ class Gemini(Model):
                             # Google recommends that if using a single image, place the text prompt after the image.
                             message_parts.insert(0, image.content)
                         else:
-                            image_content = _format_image_for_message(image)
+                            image_content = format_image_for_message(image)
                             if image_content:
                                 message_parts.append(Part.from_bytes(**image_content))
 
@@ -735,6 +629,11 @@ class Gemini(Model):
                     if hasattr(part, "text") and part.text is not None:
                         model_response.content = part.text
 
+                    if hasattr(part, "inline_data") and part.inline_data is not None:
+                        model_response.image = ImageArtifact(
+                            id=str(uuid4()), content=part.inline_data.data, mime_type=part.inline_data.mime_type
+                        )
+
                     # Extract function call if present
                     if hasattr(part, "function_call") and part.function_call is not None:
                         tool_call = {
@@ -755,16 +654,12 @@ class Gemini(Model):
                 citations.raw = grounding_metadata
 
                 # Extract url and title
-                chunks = grounding_metadata.pop("grounding_chunks", [])
-                citation_pairs = (
-                    [
-                        (chunk.get("web", {}).get("uri"), chunk.get("web", {}).get("title"))
-                        for chunk in chunks
-                        if chunk.get("web", {}).get("uri")
-                    ]
-                    if chunks
-                    else []
-                )
+                chunks = grounding_metadata.pop("grounding_chunks", None) or []
+                citation_pairs = [
+                    (chunk.get("web", {}).get("uri"), chunk.get("web", {}).get("title"))
+                    for chunk in chunks
+                    if chunk.get("web", {}).get("uri")
+                ]
 
                 # Create citation objects from filtered pairs
                 citations.urls = [UrlCitation(url=url, title=title) for url, title in citation_pairs]
@@ -797,6 +692,11 @@ class Gemini(Model):
                 if hasattr(part, "text") and part.text is not None:
                     model_response.content = part.text
 
+                if hasattr(part, "inline_data") and part.inline_data is not None:
+                    model_response.image = ImageArtifact(
+                        id=str(uuid4()), content=part.inline_data.data, mime_type=part.inline_data.mime_type
+                    )
+
                 # Extract function call if present
                 if hasattr(part, "function_call") and part.function_call is not None:
                     tool_call = {
@@ -817,7 +717,7 @@ class Gemini(Model):
             citations.raw = grounding_metadata
 
             # Extract url and title
-            chunks = grounding_metadata.pop("grounding_chunks", [])
+            chunks = grounding_metadata.pop("grounding_chunks", None) or []
             citation_pairs = [
                 (chunk.get("web", {}).get("uri"), chunk.get("web", {}).get("title"))
                 for chunk in chunks
