@@ -9,5 +9,10 @@ class OpenAILike(OpenAIChat):
     id: str = "not-provided"
     name: str = "OpenAILike"
     api_key: Optional[str] = "not-provided"
-    override_system_role: bool = False
-    system_message_role: str = "system"
+
+    role_map = {
+        "system": "system",
+        "user": "user",
+        "assistant": "assistant",
+        "tool": "tool",
+    }
