@@ -3,7 +3,7 @@ from enum import Enum
 from time import time
 from typing import Any, Dict, List, Optional
 
-from agno.media import AudioResponse
+from agno.media import AudioResponse, ImageArtifact
 from agno.models.message import Citations
 
 
@@ -24,6 +24,7 @@ class ModelResponse:
     content: Optional[str] = None
     parsed: Optional[Any] = None
     audio: Optional[AudioResponse] = None
+    image: Optional[ImageArtifact] = None
     tool_calls: List[Dict[str, Any]] = field(default_factory=list)
     event: str = ModelResponseEvent.assistant_response.value
 
