@@ -1,18 +1,24 @@
 import json
 from dataclasses import asdict
 from io import BytesIO
-from typing import AsyncGenerator, List, Optional, cast
+from typing import Any, AsyncGenerator, Dict, List, Optional, cast
+from uuid import uuid4
 
 from fastapi import APIRouter, File, Form, HTTPException, Query, UploadFile
 from fastapi.responses import JSONResponse, StreamingResponse
 
 from agno.agent.agent import Agent, RunResponse
 from agno.media import Audio, Image, Video
+from agno.media import File as FileMedia
+from agno.memory.agent import AgentMemory
+from agno.memory.v2 import Memory
 from agno.playground.operator import (
     format_tools,
     get_agent_by_id,
     get_session_title,
+    get_session_title_from_team_session,
     get_session_title_from_workflow_session,
+    get_team_by_id,
     get_workflow_by_id,
 )
 from agno.playground.schemas import (
@@ -20,26 +26,114 @@ from agno.playground.schemas import (
     AgentModel,
     AgentRenameRequest,
     AgentSessionsResponse,
+    MemoryResponse,
+    TeamGetResponse,
+    TeamRenameRequest,
+    TeamSessionResponse,
     WorkflowGetResponse,
     WorkflowRenameRequest,
     WorkflowRunRequest,
     WorkflowSessionResponse,
     WorkflowsGetResponse,
 )
+from agno.playground.utils import process_audio, process_document, process_image, process_video
 from agno.run.response import RunEvent
+from agno.run.team import TeamRunResponse
 from agno.storage.session.agent import AgentSession
+from agno.storage.session.team import TeamSession
 from agno.storage.session.workflow import WorkflowSession
+from agno.team.team import Team
 from agno.utils.log import logger
 from agno.workflow.workflow import Workflow
 
 
+async def chat_response_streamer(
+    agent: Agent,
+    message: str,
+    session_id: Optional[str] = None,
+    user_id: Optional[str] = None,
+    images: Optional[List[Image]] = None,
+    audio: Optional[List[Audio]] = None,
+    videos: Optional[List[Video]] = None,
+) -> AsyncGenerator:
+    try:
+        run_response = await agent.arun(
+            message,
+            session_id=session_id,
+            user_id=user_id,
+            images=images,
+            audio=audio,
+            videos=videos,
+            stream=True,
+            stream_intermediate_steps=True,
+        )
+        async for run_response_chunk in run_response:
+            run_response_chunk = cast(RunResponse, run_response_chunk)
+            yield run_response_chunk.to_json()
+    except Exception as e:
+        error_response = RunResponse(
+            content=str(e),
+            event=RunEvent.run_error,
+        )
+        yield error_response.to_json()
+        return
+
+
+async def team_chat_response_streamer(
+    team: Team,
+    message: str,
+    session_id: Optional[str] = None,
+    user_id: Optional[str] = None,
+    images: Optional[List[Image]] = None,
+    audio: Optional[List[Audio]] = None,
+    videos: Optional[List[Video]] = None,
+    files: Optional[List[FileMedia]] = None,
+) -> AsyncGenerator:
+    try:
+        run_response = await team.arun(
+            message,
+            session_id=session_id,
+            user_id=user_id,
+            images=images,
+            audio=audio,
+            videos=videos,
+            files=files,
+            stream=True,
+            stream_intermediate_steps=True,
+        )
+        async for run_response_chunk in run_response:
+            run_response_chunk = cast(TeamRunResponse, run_response_chunk)
+            yield run_response_chunk.to_json()
+    except Exception as e:
+        error_response = TeamRunResponse(
+            content=str(e),
+            event=RunEvent.run_error,
+        )
+        yield error_response.to_json()
+        return
+
+
 def get_async_playground_router(
-    agents: Optional[List[Agent]] = None, workflows: Optional[List[Workflow]] = None
+    agents: Optional[List[Agent]] = None, workflows: Optional[List[Workflow]] = None, teams: Optional[List[Team]] = None
 ) -> APIRouter:
     playground_router = APIRouter(prefix="/playground", tags=["Playground"])
 
-    if agents is None and workflows is None:
-        raise ValueError("Either agents or workflows must be provided.")
+    if agents is None and workflows is None and teams is None:
+        raise ValueError("Either agents, teams or workflows must be provided.")
+
+    # Generate IDs if they were not explicitly set on agents/teams/workflows
+    if agents:
+        for agent in agents:
+            if agent.agent_id is None:
+                agent.agent_id = str(uuid4())
+    if teams:
+        for team in teams:
+            if team.team_id is None:
+                team.team_id = str(uuid4())
+    if workflows:
+        for workflow in workflows:
+            if workflow.workflow_id is None:
+                workflow.workflow_id = str(uuid4())
 
     @playground_router.get("/status")
     async def playground_status():
@@ -52,7 +146,7 @@ def get_async_playground_router(
             return agent_list
 
         for agent in agents:
-            agent_tools = agent.get_tools()
+            agent_tools = agent.get_tools(session_id=str(uuid4()))
             formatted_tools = format_tools(agent_tools)
 
             name = agent.model.name or agent.model.__class__.__name__ if agent.model else None
@@ -72,6 +166,26 @@ def get_async_playground_router(
             else:
                 provider = ""
 
+            if agent.memory:
+                memory_dict: Optional[Dict[str, Any]] = {}
+                if isinstance(agent.memory, AgentMemory) and agent.memory.db:
+                    memory_dict = {"name": agent.memory.db.__class__.__name__}
+                elif isinstance(agent.memory, Memory) and agent.memory.db:
+                    memory_dict = {"name": "Memory"}
+                    if agent.memory.model is not None:
+                        memory_dict["model"] = AgentModel(
+                            name=agent.memory.model.name,
+                            model=agent.memory.model.id,
+                            provider=agent.memory.model.provider,
+                        )
+                    if agent.memory.db is not None:
+                        memory_dict["db"] = agent.memory.db.__dict__()  # type: ignore
+
+                else:
+                    memory_dict = None
+            else:
+                memory_dict = None
+
             agent_list.append(
                 AgentGetResponse(
                     agent_id=agent.agent_id,
@@ -83,7 +197,7 @@ def get_async_playground_router(
                     ),
                     add_context=agent.add_context,
                     tools=formatted_tools,
-                    memory={"name": agent.memory.db.__class__.__name__} if agent.memory and agent.memory.db else None,
+                    memory=memory_dict,
                     storage={"name": agent.storage.__class__.__name__} if agent.storage else None,
                     knowledge={"name": agent.knowledge.__class__.__name__} if agent.knowledge else None,
                     description=agent.description,
@@ -93,56 +207,6 @@ def get_async_playground_router(
 
         return agent_list
 
-    async def chat_response_streamer(
-        agent: Agent,
-        message: str,
-        images: Optional[List[Image]] = None,
-        audio: Optional[List[Audio]] = None,
-        videos: Optional[List[Video]] = None,
-    ) -> AsyncGenerator:
-        try:
-            run_response = await agent.arun(
-                message,
-                images=images,
-                audio=audio,
-                videos=videos,
-                stream=True,
-                stream_intermediate_steps=True,
-            )
-            async for run_response_chunk in run_response:
-                run_response_chunk = cast(RunResponse, run_response_chunk)
-                yield run_response_chunk.to_json()
-        except Exception as e:
-            error_response = RunResponse(
-                content=str(e),
-                event=RunEvent.run_error,
-            )
-            yield error_response.to_json()
-            return
-
-    async def process_image(file: UploadFile) -> Image:
-        content = file.file.read()
-
-        return Image(content=content)
-
-    async def process_audio(file: UploadFile) -> Audio:
-        content = file.file.read()
-        if not content:
-            raise HTTPException(status_code=400, detail="Empty file")
-        format = None
-        if file.filename and "." in file.filename:
-            format = file.filename.split(".")[-1].lower()
-        elif file.content_type:
-            format = file.content_type.split("/")[-1]
-
-        return Audio(content=content, format=format)
-
-    async def process_video(file: UploadFile) -> Video:
-        content = file.file.read()
-        if not content:
-            raise HTTPException(status_code=400, detail="Empty file")
-        return Video(content=content, format=file.content_type)
-
     @playground_router.post("/agents/{agent_id}/runs")
     async def create_agent_run(
         agent_id: str,
@@ -158,38 +222,34 @@ def get_async_playground_router(
         if agent is None:
             raise HTTPException(status_code=404, detail="Agent not found")
 
-        if session_id is not None:
+        if session_id is not None and session_id != "":
             logger.debug(f"Continuing session: {session_id}")
         else:
             logger.debug("Creating new session")
-
-        # Create a new instance of this agent
-        new_agent_instance = agent.deep_copy(update={"session_id": session_id})
-        new_agent_instance.session_name = None
-        if user_id is not None:
-            new_agent_instance.user_id = user_id
+            session_id = str(uuid4())
 
         if monitor:
-            new_agent_instance.monitoring = True
+            agent.monitoring = True
         else:
-            new_agent_instance.monitoring = False
+            agent.monitoring = False
 
         base64_images: List[Image] = []
         base64_audios: List[Audio] = []
         base64_videos: List[Video] = []
+
         if files:
             for file in files:
                 logger.info(f"Processing file: {file.content_type}")
                 if file.content_type in ["image/png", "image/jpeg", "image/jpg", "image/webp"]:
                     try:
-                        base64_image = await process_image(file)
+                        base64_image = process_image(file)
                         base64_images.append(base64_image)
                     except Exception as e:
                         logger.error(f"Error processing image {file.filename}: {e}")
                         continue
                 elif file.content_type in ["audio/wav", "audio/mp3", "audio/mpeg"]:
                     try:
-                        base64_audio = await process_audio(file)
+                        base64_audio = process_audio(file)
                         base64_audios.append(base64_audio)
                     except Exception as e:
                         logger.error(f"Error processing audio {file.filename}: {e}")
@@ -208,14 +268,14 @@ def get_async_playground_router(
                     "video/3gpp",
                 ]:
                     try:
-                        base64_video = await process_video(file)
+                        base64_video = process_video(file)
                         base64_videos.append(base64_video)
                     except Exception as e:
                         logger.error(f"Error processing video {file.filename}: {e}")
                         continue
                 else:
                     # Check for knowledge base before processing documents
-                    if new_agent_instance.knowledge is None:
+                    if agent.knowledge is None:
                         raise HTTPException(status_code=404, detail="KnowledgeBase not found")
 
                     if file.content_type == "application/pdf":
@@ -225,8 +285,8 @@ def get_async_playground_router(
                         pdf_file = BytesIO(contents)
                         pdf_file.name = file.filename
                         file_content = PDFReader().read(pdf_file)
-                        if new_agent_instance.knowledge is not None:
-                            new_agent_instance.knowledge.load_documents(file_content)
+                        if agent.knowledge is not None:
+                            agent.knowledge.load_documents(file_content)
                     elif file.content_type == "text/csv":
                         from agno.document.reader.csv_reader import CSVReader
 
@@ -234,8 +294,8 @@ def get_async_playground_router(
                         csv_file = BytesIO(contents)
                         csv_file.name = file.filename
                         file_content = CSVReader().read(csv_file)
-                        if new_agent_instance.knowledge is not None:
-                            new_agent_instance.knowledge.load_documents(file_content)
+                        if agent.knowledge is not None:
+                            agent.knowledge.load_documents(file_content)
                     elif file.content_type == "application/vnd.openxmlformats-officedocument.wordprocessingml.document":
                         from agno.document.reader.docx_reader import DocxReader
 
@@ -243,8 +303,8 @@ def get_async_playground_router(
                         docx_file = BytesIO(contents)
                         docx_file.name = file.filename
                         file_content = DocxReader().read(docx_file)
-                        if new_agent_instance.knowledge is not None:
-                            new_agent_instance.knowledge.load_documents(file_content)
+                        if agent.knowledge is not None:
+                            agent.knowledge.load_documents(file_content)
                     elif file.content_type == "text/plain":
                         from agno.document.reader.text_reader import TextReader
 
@@ -252,8 +312,8 @@ def get_async_playground_router(
                         text_file = BytesIO(contents)
                         text_file.name = file.filename
                         file_content = TextReader().read(text_file)
-                        if new_agent_instance.knowledge is not None:
-                            new_agent_instance.knowledge.load_documents(file_content)
+                        if agent.knowledge is not None:
+                            agent.knowledge.load_documents(file_content)
 
                     elif file.content_type == "application/json":
                         from agno.document.reader.json_reader import JSONReader
@@ -262,16 +322,18 @@ def get_async_playground_router(
                         json_file = BytesIO(contents)
                         json_file.name = file.filename
                         file_content = JSONReader().read(json_file)
-                        if new_agent_instance.knowledge is not None:
-                            new_agent_instance.knowledge.load_documents(file_content)
+                        if agent.knowledge is not None:
+                            agent.knowledge.load_documents(file_content)
                     else:
                         raise HTTPException(status_code=400, detail="Unsupported file type")
 
         if stream:
             return StreamingResponse(
                 chat_response_streamer(
-                    new_agent_instance,
+                    agent,
                     message,
+                    session_id=session_id,
+                    user_id=user_id,
                     images=base64_images if base64_images else None,
                     audio=base64_audios if base64_audios else None,
                     videos=base64_videos if base64_videos else None,
@@ -281,8 +343,10 @@ def get_async_playground_router(
         else:
             run_response = cast(
                 RunResponse,
-                await new_agent_instance.arun(
+                await agent.arun(
                     message=message,
+                    session_id=session_id,
+                    user_id=user_id,
                     images=base64_images if base64_images else None,
                     audio=base64_audios if base64_audios else None,
                     videos=base64_videos if base64_videos else None,
@@ -329,7 +393,30 @@ def get_async_playground_router(
         if agent_session is None:
             return JSONResponse(status_code=404, content="Session not found.")
 
-        return agent_session
+        agent_session_dict = agent_session.to_dict()
+        if agent_session.memory is not None:
+            runs = agent_session.memory.get("runs")
+            if runs is not None:
+                first_run = runs[0]
+                # This is how we know it is a RunResponse
+                if "content" in first_run:
+                    agent_session_dict["runs"] = []
+
+                    for run in runs:
+                        first_user_message = None
+                        for msg in run.get("messages", []):
+                            if msg.get("role") == "user" and msg.get("from_history", False) is False:
+                                first_user_message = msg
+                                break
+                        # Remove the memory from the response
+                        run.pop("memory", None)
+                        agent_session_dict["runs"].append(
+                            {
+                                "message": first_user_message,
+                                "response": run,
+                            }
+                        )
+        return agent_session_dict
 
     @playground_router.post("/agents/{agent_id}/sessions/{session_id}/rename")
     async def rename_agent_session(agent_id: str, session_id: str, body: AgentRenameRequest):
@@ -343,8 +430,7 @@ def get_async_playground_router(
         all_agent_sessions: List[AgentSession] = agent.storage.get_all_sessions(user_id=body.user_id)  # type: ignore
         for session in all_agent_sessions:
             if session.session_id == session_id:
-                agent.session_id = session_id
-                agent.rename_session(body.name)
+                agent.rename_session(body.name, session_id=session_id)
                 return JSONResponse(content={"message": f"successfully renamed session {session.session_id}"})
 
         return JSONResponse(status_code=404, content="Session not found.")
@@ -366,6 +452,24 @@ def get_async_playground_router(
 
         return JSONResponse(status_code=404, content="Session not found.")
 
+    @playground_router.get("/agents/{agent_id}/memories")
+    async def get_agent_memories(agent_id: str, user_id: str = Query(..., min_length=1)):
+        agent = get_agent_by_id(agent_id, agents)
+        if agent is None:
+            return JSONResponse(status_code=404, content="Agent not found.")
+
+        if agent.memory is None:
+            return JSONResponse(status_code=404, content="Agent does not have memory enabled.")
+
+        if isinstance(agent.memory, Memory):
+            memories = agent.memory.get_user_memories(user_id=user_id)
+            return [
+                MemoryResponse(memory=memory.memory, topics=memory.topics, last_updated=memory.last_updated)
+                for memory in memories
+            ]
+        else:
+            return []
+
     @playground_router.get("/workflows", response_model=List[WorkflowsGetResponse])
     async def get_workflows():
         if workflows is None:
@@ -440,7 +544,7 @@ def get_async_playground_router(
         # Retrieve all sessions for the given workflow and user
         try:
             all_workflow_sessions: List[WorkflowSession] = workflow.storage.get_all_sessions(
-                user_id=user_id, workflow_id=workflow_id
+                user_id=user_id, entity_id=workflow_id
             )  # type: ignore
         except Exception as e:
             raise HTTPException(status_code=500, detail=f"Error retrieving sessions: {str(e)}")
@@ -499,4 +603,246 @@ def get_async_playground_router(
         workflow.delete_session(session_id)
         return JSONResponse(content={"message": f"successfully deleted workflow {workflow.name}"})
 
+    @playground_router.get("/teams")
+    async def get_teams():
+        if teams is None:
+            return []
+
+        return [TeamGetResponse.from_team(team) for team in teams]
+
+    @playground_router.get("/teams/{team_id}")
+    async def get_team(team_id: str):
+        team = get_team_by_id(team_id, teams)
+        if team is None:
+            raise HTTPException(status_code=404, detail="Team not found")
+
+        return TeamGetResponse.from_team(team)
+
+    @playground_router.post("/teams/{team_id}/runs")
+    async def create_team_run(
+        team_id: str,
+        message: str = Form(...),
+        stream: bool = Form(True),
+        monitor: bool = Form(True),
+        session_id: Optional[str] = Form(None),
+        user_id: Optional[str] = Form(None),
+        files: Optional[List[UploadFile]] = File(None),
+    ):
+        logger.debug(f"Creating team run: {message} {session_id} {monitor} {user_id} {team_id} {files}")
+        team = get_team_by_id(team_id, teams)
+        if team is None:
+            raise HTTPException(status_code=404, detail="Team not found")
+
+        if session_id is not None and session_id != "":
+            logger.debug(f"Continuing session: {session_id}")
+        else:
+            logger.debug("Creating new session")
+            session_id = str(uuid4())
+
+        if monitor:
+            team.monitoring = True
+        else:
+            team.monitoring = False
+
+        base64_images: List[Image] = []
+        base64_audios: List[Audio] = []
+        base64_videos: List[Video] = []
+        document_files: List[FileMedia] = []
+
+        if files:
+            for file in files:
+                if file.content_type in ["image/png", "image/jpeg", "image/jpg", "image/webp"]:
+                    try:
+                        base64_image = process_image(file)
+                        base64_images.append(base64_image)
+                    except Exception as e:
+                        logger.error(f"Error processing image {file.filename}: {e}")
+                        continue
+                elif file.content_type in ["audio/wav", "audio/mp3", "audio/mpeg"]:
+                    try:
+                        base64_audio = process_audio(file)
+                        base64_audios.append(base64_audio)
+                    except Exception as e:
+                        logger.error(f"Error processing audio {file.filename}: {e}")
+                        continue
+                elif file.content_type in [
+                    "video/x-flv",
+                    "video/quicktime",
+                    "video/mpeg",
+                    "video/mpegs",
+                    "video/mpgs",
+                    "video/mpg",
+                    "video/mpg",
+                    "video/mp4",
+                    "video/webm",
+                    "video/wmv",
+                    "video/3gpp",
+                ]:
+                    try:
+                        base64_video = process_video(file)
+                        base64_videos.append(base64_video)
+                    except Exception as e:
+                        logger.error(f"Error processing video {file.filename}: {e}")
+                        continue
+                elif file.content_type in [
+                    "application/pdf",
+                    "text/csv",
+                    "application/vnd.openxmlformats-officedocument.wordprocessingml.document",
+                    "text/plain",
+                    "application/json",
+                ]:
+                    document_file = process_document(file)
+                    if document_file is not None:
+                        document_files.append(document_file)
+                else:
+                    raise HTTPException(status_code=400, detail="Unsupported file type")
+
+        if stream:
+            return StreamingResponse(
+                team_chat_response_streamer(
+                    team,
+                    message,
+                    session_id=session_id,
+                    user_id=user_id,
+                    images=base64_images if base64_images else None,
+                    audio=base64_audios if base64_audios else None,
+                    videos=base64_videos if base64_videos else None,
+                    files=document_files if document_files else None,
+                ),
+                media_type="text/event-stream",
+            )
+        else:
+            run_response = await team.arun(
+                message=message,
+                session_id=session_id,
+                user_id=user_id,
+                images=base64_images if base64_images else None,
+                audio=base64_audios if base64_audios else None,
+                videos=base64_videos if base64_videos else None,
+                files=document_files if document_files else None,
+                stream=False,
+            )
+            return run_response.to_dict()
+
+    @playground_router.get("/teams/{team_id}/sessions", response_model=List[TeamSessionResponse])
+    async def get_all_team_sessions(team_id: str, user_id: Optional[str] = Query(None, min_length=1)):
+        team = get_team_by_id(team_id, teams)
+        if team is None:
+            raise HTTPException(status_code=404, detail="Team not found")
+
+        if team.storage is None:
+            raise HTTPException(status_code=404, detail="Team does not have storage enabled")
+
+        try:
+            all_team_sessions: List[TeamSession] = team.storage.get_all_sessions(user_id=user_id, entity_id=team_id)  # type: ignore
+        except Exception as e:
+            raise HTTPException(status_code=500, detail=f"Error retrieving sessions: {str(e)}")
+
+        team_sessions: List[TeamSessionResponse] = []
+        for session in all_team_sessions:
+            title = get_session_title_from_team_session(session)
+            team_sessions.append(
+                TeamSessionResponse(
+                    title=title,
+                    session_id=session.session_id,
+                    session_name=session.session_data.get("session_name") if session.session_data else None,
+                    created_at=session.created_at,
+                )
+            )
+        return team_sessions
+
+    @playground_router.get("/teams/{team_id}/sessions/{session_id}")
+    async def get_team_session(team_id: str, session_id: str, user_id: Optional[str] = Query(None, min_length=1)):
+        team = get_team_by_id(team_id, teams)
+        if team is None:
+            raise HTTPException(status_code=404, detail="Team not found")
+
+        if team.storage is None:
+            raise HTTPException(status_code=404, detail="Team does not have storage enabled")
+
+        try:
+            team_session: Optional[TeamSession] = team.storage.read(session_id, user_id)  # type: ignore
+        except Exception as e:
+            raise HTTPException(status_code=500, detail=f"Error retrieving session: {str(e)}")
+
+        if not team_session:
+            raise HTTPException(status_code=404, detail="Session not found")
+
+        team_session_dict = team_session.to_dict()
+        if team_session.memory is not None:
+            runs = team_session.memory.get("runs")
+            if runs is not None:
+                first_run = runs[0]
+                # This is how we know it is a RunResponse
+                if "content" in first_run:
+                    team_session_dict["runs"] = []
+                    for run in runs:
+                        first_user_message = None
+                        for msg in run.get("messages", []):
+                            if msg.get("role") == "user" and msg.get("from_history", False) is False:
+                                first_user_message = msg
+                                break
+                        # Remove the memory from the response
+                        team_session_dict.pop("memory", None)
+                        team_session_dict["runs"].append(
+                            {
+                                "message": first_user_message,
+                                "response": run,
+                            }
+                        )
+
+        return team_session_dict
+
+    @playground_router.post("/teams/{team_id}/sessions/{session_id}/rename")
+    async def rename_team_session(team_id: str, session_id: str, body: TeamRenameRequest):
+        team = get_team_by_id(team_id, teams)
+        if team is None:
+            raise HTTPException(status_code=404, detail="Team not found")
+
+        if team.storage is None:
+            raise HTTPException(status_code=404, detail="Team does not have storage enabled")
+
+        all_team_sessions: List[TeamSession] = team.storage.get_all_sessions(user_id=body.user_id, entity_id=team_id)  # type: ignore
+        for session in all_team_sessions:
+            if session.session_id == session_id:
+                team.rename_session(body.name, session_id=session_id)
+                return JSONResponse(content={"message": f"successfully renamed team session {body.name}"})
+
+        raise HTTPException(status_code=404, detail="Session not found")
+
+    @playground_router.delete("/teams/{team_id}/sessions/{session_id}")
+    async def delete_team_session(team_id: str, session_id: str, user_id: Optional[str] = Query(None, min_length=1)):
+        team = get_team_by_id(team_id, teams)
+        if team is None:
+            raise HTTPException(status_code=404, detail="Team not found")
+
+        if team.storage is None:
+            raise HTTPException(status_code=404, detail="Team does not have storage enabled")
+
+        all_team_sessions: List[TeamSession] = team.storage.get_all_sessions(user_id=user_id, entity_id=team_id)  # type: ignore
+        for session in all_team_sessions:
+            if session.session_id == session_id:
+                team.delete_session(session_id)
+                return JSONResponse(content={"message": f"successfully deleted team session {session_id}"})
+
+        raise HTTPException(status_code=404, detail="Session not found")
+
+    @playground_router.get("/team/{team_id}/memories")
+    async def get_team_memories(team_id: str, user_id: str = Query(..., min_length=1)):
+        team = get_team_by_id(team_id, teams)
+        if team is None:
+            return JSONResponse(status_code=404, content="Teem not found.")
+
+        if team.memory is None:
+            return JSONResponse(status_code=404, content="Team does not have memory enabled.")
+
+        if isinstance(team.memory, Memory):
+            memories = team.memory.get_user_memories(user_id=user_id)
+            return [
+                MemoryResponse(memory=memory.memory, topics=memory.topics, last_updated=memory.last_updated)
+                for memory in memories
+            ]
+        else:
+            return []
+
     return playground_router
