@@ -91,6 +91,7 @@ class DynamoDbStorage(Storage):
             if e.response["Error"]["Code"] == "ResourceNotFoundException":
                 log_debug(f"Creating table '{self.table_name}'.")
 
+                attribute_definitions = []
                 if self.mode == "agent":
                     attribute_definitions = [
                         {"AttributeName": "session_id", "AttributeType": "S"},
@@ -107,7 +108,7 @@ class DynamoDbStorage(Storage):
                         {"AttributeName": "team_session_id", "AttributeType": "S"},
                         {"AttributeName": "created_at", "AttributeType": "N"},
                     ]
-                else:
+                elif self.mode == "workflow":
                     attribute_definitions = [
                         {"AttributeName": "session_id", "AttributeType": "S"},
                         {"AttributeName": "user_id", "AttributeType": "S"},
@@ -159,7 +160,7 @@ class DynamoDbStorage(Storage):
                             },
                         }
                     )
-                else:
+                elif self.mode == "workflow":
                     secondary_indexes.append(
                         {
                             "IndexName": "workflow_id-index",
@@ -259,14 +260,14 @@ class DynamoDbStorage(Storage):
                         KeyConditionExpression=Key("team_id").eq(entity_id),
                         ProjectionExpression="session_id",
                     )
-                else:
+                elif self.mode == "workflow":
                     # Query using workflow_id index
                     response = self.table.query(
                         IndexName="workflow_id-index",
                         KeyConditionExpression=Key("workflow_id").eq(entity_id),
                         ProjectionExpression="session_id",
                     )
-                items = response.get("Items", [])
+                items = response.get("Items", [])  # type: ignore
                 session_ids.extend([item["session_id"] for item in items if "session_id" in item])
             else:
                 # Scan the whole table
@@ -305,14 +306,15 @@ class DynamoDbStorage(Storage):
                         KeyConditionExpression=Key("user_id").eq(user_id),
                         ProjectionExpression="session_id, team_id, user_id, team_session_id, memory, team_data, session_data, extra_data, created_at, updated_at",
                     )
-                else:
+                elif self.mode == "workflow":
                     # Query using user_id index
                     response = self.table.query(
                         IndexName="user_id-index",
                         KeyConditionExpression=Key("user_id").eq(user_id),
                         ProjectionExpression="session_id, workflow_id, user_id, memory, workflow_data, session_data, extra_data, created_at, updated_at",
                     )
-                items = response.get("Items", [])
+
+                items = response.get("Items", [])  # type: ignore
                 for item in items:
                     item = self._deserialize_item(item)
                     _session: Optional[Session] = None
@@ -337,14 +339,14 @@ class DynamoDbStorage(Storage):
                         KeyConditionExpression=Key("team_id").eq(entity_id),
                         ProjectionExpression="session_id, team_id, user_id, team_session_id, memory, team_data, session_data, extra_data, created_at, updated_at",
                     )
-                else:
+                elif self.mode == "workflow":
                     # Query using workflow_id index
                     response = self.table.query(
                         IndexName="workflow_id-index",
                         KeyConditionExpression=Key("workflow_id").eq(entity_id),
                         ProjectionExpression="session_id, workflow_id, user_id, memory, workflow_data, session_data, extra_data, created_at, updated_at",
                     )
-                items = response.get("Items", [])
+                items = response.get("Items", [])  # type: ignore
                 for item in items:
                     item = self._deserialize_item(item)
                     if self.mode == "agent":
@@ -363,7 +365,7 @@ class DynamoDbStorage(Storage):
                     response = self.table.scan(
                         ProjectionExpression="session_id, team_id, user_id, team_session_id, memory, team_data, session_data, extra_data, created_at, updated_at"
                     )
-                else:
+                elif self.mode == "workflow":
                     response = self.table.scan(
                         ProjectionExpression="session_id, workflow_id, user_id, memory, workflow_data, session_data, extra_data, created_at, updated_at"
                     )
