@@ -10,8 +10,8 @@ class AWSLambdaTools(Toolkit):
     name: str = "AWSLambdaTool"
     description: str = "A tool for interacting with AWS Lambda functions"
 
-    def __init__(self, region_name: str = "us-east-1"):
-        super().__init__()
+    def __init__(self, region_name: str = "us-east-1", **kwargs):
+        super().__init__(name="aws-lambda", **kwargs)
         self.client = boto3.client("lambda", region_name=region_name)
         self.register(self.list_functions)
         self.register(self.invoke_function)
