@@ -1,9 +1,10 @@
 from os import getenv
-from typing import Literal, Optional
+from typing import Literal, Optional, Union
 from uuid import uuid4
 
 from agno.agent import Agent
 from agno.media import ImageArtifact
+from agno.team.team import Team
 from agno.tools import Toolkit
 from agno.utils.log import log_debug, logger
 
@@ -23,8 +24,9 @@ class DalleTools(Toolkit):
         quality: Literal["standard", "hd"] = "standard",
         style: Literal["vivid", "natural"] = "vivid",
         api_key: Optional[str] = None,
+        **kwargs,
     ):
-        super().__init__(name="dalle")
+        super().__init__(name="dalle", **kwargs)
 
         self.model = model
         self.n = n
@@ -56,7 +58,7 @@ class DalleTools(Toolkit):
         # - Add support for saving images
         # - Add support for editing images
 
-    def create_image(self, agent: Agent, prompt: str) -> str:
+    def create_image(self, agent: Union[Agent, Team], prompt: str) -> str:
         """Use this function to generate an image for a prompt.
 
         Args:
