@@ -11,8 +11,10 @@ class EmailTools(Toolkit):
         sender_name: Optional[str] = None,
         sender_email: Optional[str] = None,
         sender_passkey: Optional[str] = None,
+        **kwargs,
     ):
-        super().__init__(name="email_tools")
+        super().__init__(name="email_tools", **kwargs)
+
         self.receiver_email: Optional[str] = receiver_email
         self.sender_name: Optional[str] = sender_name
         self.sender_email: Optional[str] = sender_email
