@@ -4,12 +4,15 @@ from typing import Iterable, Union
 from pydantic import BaseModel
 
 from agno.run.response import RunResponse
+from agno.run.team import TeamRunResponse
 from agno.utils.log import logger
 from agno.utils.timer import Timer
 
 
 def pprint_run_response(
-    run_response: Union[RunResponse, Iterable[RunResponse]], markdown: bool = False, show_time: bool = False
+    run_response: Union[RunResponse, Iterable[RunResponse], TeamRunResponse, Iterable[TeamRunResponse]],
+    markdown: bool = False,
+    show_time: bool = False,
 ) -> None:
     from rich.box import ROUNDED
     from rich.json import JSON
@@ -21,7 +24,7 @@ def pprint_run_response(
     from agno.cli.console import console
 
     # If run_response is a single RunResponse, wrap it in a list to make it iterable
-    if isinstance(run_response, RunResponse):
+    if isinstance(run_response, RunResponse) or isinstance(run_response, TeamRunResponse):
         single_response_content: Union[str, JSON, Markdown] = ""
         if isinstance(run_response.content, str):
             single_response_content = (
@@ -49,7 +52,9 @@ def pprint_run_response(
             response_timer = Timer()
             response_timer.start()
             for resp in run_response:
-                if isinstance(resp, RunResponse) and isinstance(resp.content, str):
+                if (isinstance(resp, RunResponse) or isinstance(resp, TeamRunResponse)) and isinstance(
+                    resp.content, str
+                ):
                     streaming_response_content += resp.content
 
                 formatted_response = Markdown(streaming_response_content) if markdown else streaming_response_content  # type: ignore
