@@ -518,3 +518,6 @@ class LanceDb(VectorDb):
         except Exception as e:
             logger.error(f"Error checking name existence: {e}")
             return False
+
+    async def async_name_exists(self, name: str) -> bool:
+        raise NotImplementedError(f"Async not supported on {self.__class__.__name__}.")
