@@ -1,3 +1,3 @@
 from agno.vectordb.distance import Distance
 from agno.vectordb.singlestore.index import HNSWFlat, Ivfflat
-from agno.vectordb.singlestore.s2vectordb import S2VectorDb
+from agno.vectordb.singlestore.singlestore import SingleStore
